# medaka

**DOI:** [10.5281/zenodo.7846294](https://doi.org/10.5281/zenodo.7846294)

## Available Versions
- **Version 1.7.3**
  - [Download](https://zenodo.org/record/7846295/files/medaka_1.7.3.img)
  - **MD5:** `a8b4d81c24f50055c22550dc6810b46d`
  - **DOI:** [10.5281/zenodo.7846295](https://doi.org/10.5281/zenodo.7846295)
  - **Size:** 3175.91 MB
  - **Binaries:** 0 available

## Binaries (3 total)

```medaka medaka_consensus medaka_counts```
